<?php
namespace Reaktion\Api;

use WP_REST_Request;

class Orders_Filters extends Api
{
    const AFTER_CREATED = 'reaktion_after_created';
    const AFTER_MODIFIED = 'reaktion_after_modified';
    const BEFORE_CREATED = 'reaktion_before_created';
    const BEFORE_MODIFIED = 'reaktion_before_modified';
    const COLUMN_CREATED = 'post_date_gmt';
    const COLUMN_MODIFIED = 'post_modified_gmt';

    public function __construct()
    {
        add_filter(
            'woocommerce_rest_orders_prepare_object_query',
            [$this, 'handle_prepare'],
            10,
            2
        );
    }

    public function handle_prepare(array $args, WP_REST_Request $request)
    {
        $args = $this->apply_period(
            $args,
            $request,
            static::COLUMN_CREATED,
            static::AFTER_CREATED,
            static::BEFORE_CREATED
        );
        $args = $this->apply_period(
            $args,
            $request,
            static::COLUMN_MODIFIED,
            static::AFTER_MODIFIED,
            static::BEFORE_MODIFIED
        );
        return $args;
    }

    /**
     * @param string $date_column
     * @param string $after_field
     * @param string $before_field
     * @return array
     */
    private function apply_period(
        array $args,
        WP_REST_Request $request,
        $date_column,
        $after_field,
        $before_field
    ) {
        $after_value = $this->valid_datetime($request, $after_field);
        if (!empty($after_value)) {
            $args['date_query'][] = [
                'after' => $after_value,
                'column' => $date_column,
                'inclusive' => true,
            ];
        }

        $before_value = $this->valid_datetime($request, $before_field);
        if (!empty($before_value)) {
            $args['date_query'][] = [
                'before' => $before_value,
                'column' => $date_column,
                'inclusive' => false,
            ];
        }

        return $args;
    }

    /** @return string|null */
    private function valid_datetime(WP_REST_Request $request, $field)
    {
        $value = $request->get_param($field);

        if (empty($value)) {
            return null;
        }

        if (!strtotime($value)) {
            $this->error_response($field, 'Invalid datetime string');
        }

        return $value;
    }
}
