<?php
namespace Reaktion\Api;

use WP_Query;
use WP_REST_Request;

class Orders_Sort extends Api
{
    const ORDER = 'reaktion_order';
    const ORDER_VALUES = ['asc', 'desc'];
    const SORT = 'reaktion_orderby';
    /** @var string[] sort column keyed by field value */
    const SORT_VALUES = [
        'created' => 'post_date_gmt',
        'modified' => 'post_modified_gmt',
    ];

    public function __construct()
    {
        add_filter(
            'woocommerce_rest_orders_prepare_object_query',
            [$this, 'handle_prepare'],
            10,
            2
        );
        add_filter('posts_orderby', [$this, 'handle_replace'], 10, 2);
    }

    public function handle_prepare(array $args, WP_REST_Request $request)
    {
        $sort_value = $this->valid_enum(
            $request,
            static::SORT,
            array_keys(static::SORT_VALUES)
        );
        if (!empty($sort_value)) {
            $args[static::SORT] = static::SORT_VALUES[$sort_value];
            $order_value = $this->valid_enum(
                $request,
                static::ORDER,
                static::ORDER_VALUES
            );
            $args[static::ORDER] = $order_value ?: static::ORDER_VALUES[0];
        }

        return $args;
    }

    public function handle_replace($orderby, WP_Query $query)
    {
        if (
            !empty($query->query_vars[static::SORT]) &&
            !empty($query->query_vars[static::ORDER])
        ) {
            $table = strtok($orderby, '.');
            return "{$table}.{$query->query_vars[static::SORT]} {$query->query_vars[static::ORDER]}";
        }
        return $orderby;
    }

    /**
     * @param string $field
     * @return string|null
     */
    private function valid_enum(
        WP_REST_Request $request,
        $field,
        array $whitelist
    ) {
        $value = $request->get_param($field);

        if (empty($value)) {
            return null;
        }

        if (!in_array($value, $whitelist)) {
            $this->error_response($field, 'Unknown value');
        }

        return $value;
    }
}
