<?php
namespace Reaktion\Settings;

use WC_Settings_Page;

class Reaktion_Settings_Page extends WC_Settings_Page
{
    protected $id = 'reaktion';
    protected $label = 'Reaktion';

    public function add_settings_page($pages)
    {
        // Do not register menu entry as there's nothing to edit.
        return $pages;
    }

    /** @return array */
    public function get_settings()
    {
        $settings = [
            [
                'css' => 'display:none; visibility: hidden;',
                'id' => Reaktion_Settings::OPTION_TRACKING_SCRIPT_URL,
                'type' => 'text',
            ],
            [
                'css' => 'display:none; visibility: hidden;',
                'default' => $this->timezone_string(),
                'id' => Reaktion_Settings::OPTION_TIMEZONE,
                'type' => 'text',
            ],
        ];

        return apply_filters(
            'woocommerce_get_settings_' . $this->id,
            $settings
        );
    }

    private function timezone_string()
    {
        if (function_exists('wp_timezone_string')) {
            return wp_timezone_string();
        }

        $timezone_string = get_option('timezone_string');
        if (!empty($timezone_string)) {
            return $timezone_string;
        }

        $offset = (float) get_option('gmt_offset');
        $hours = (int) $offset;
        $minutes = $offset - $hours;

        $sign = $offset < 0 ? '-' : '+';
        $abs_hour = abs($hours);
        $abs_min = abs($minutes * 60);
        $tz_offset = sprintf('%s%02d:%02d', $sign, $abs_hour, $abs_min);

        return $tz_offset;
    }
}
